<?php
ini_set('display_errors', 'On');
error_reporting(E_ALL);

/* The following code will create/update profile data in the PROFILE table 
the value returned will include a message that states if the user has been 'created'
or is 'existing' and the users friends if he has any*/

// array for JSON response
$response = array();

// check for required fields
if (isset($_POST['email']) && isset($_POST['androidId']) && isset($_POST['personName']) && isset($_POST['regId']) && $_POST['email']!="") {
	$email = $_POST['email'];
	$androidId = $_POST['androidId'];
	$name = $_POST['personName'];
	$regId = $_POST['regId'];
	
	// include db config class
	require_once __DIR__ . '/db_config.php';
	
	// connecting to db
    	$mysqli = new mysqli(DB_SERVER, DB_USER, DB_PASSWORD, DB_DATABASE);
    	
    	//check if reg id already exists
    	if($stmt = $mysqli->prepare("SELECT EMAIL, NAME, REG_ID FROM PROFILE WHERE ANDROID_ID = ?")){
    	
    		// Bind a variable to the parameter as a string. 
    		$stmt->bind_param("s", $androidId);
    		
    		// Execute the statement.
	    	$stmt->execute();  
	    	
	    	// store result
    		$stmt->store_result();
    		    		
		//get number of rows returned
    		$num_rows = $stmt->num_rows;        				    		
    		
    		//if android id already exists
    		if($num_rows > 0){
    			//get email and name associated with the android_id
    			$stmt->bind_result($curr_email, $curr_name, $curr_reg_id);
    			
    			//if email or name or reg id is different from what users wants to add the update the email and name and reg id
    			if(strcmp($curr_email, $email) != 0 || strcmp($curr_name, $name) != 0 || strcmp($curr_reg_id, $regId) != 0) {
    		
    				if($stmt = $mysqli->prepare("UPDATE PROFILE SET EMAIL = ?, NAME = ?, REG_ID = ? WHERE ANDROID_ID = ?")){    		
    					$stmt->bind_param("ssss", $email, $name, $regId, $androidId);
    					$result = $stmt->execute();

    					// email/name has been updated succesfully
    					if($result){ 
    						//return friends list
		    				getFriends($email, $mysqli);
    					}
    					//else return error
    					else{    					    		
    						$response["success"] = 0;
				        	$response["message"] = mysqli_error($mysqli);
				 
					        // echoing JSON response
				        	echo json_encode($response);
    					}
    				}
    				else{
    					$response["success"] = 0;
				        $response["message"] = "Failed to update email and name in database";
				 
					// echoing JSON response
				        echo json_encode($response);
    				}    			
    			}
    			//else email and name are same in db as what is sent by the user
    			else{
    				//return friends list
    				getFriends($email, $mysqli);
    			}    			    			
    		}    		
    		//if no rows exist for the android id then insert the record
    		elseif($num_rows == 0){
    			// inserting a new row
    			if($stmt = $mysqli->prepare("INSERT INTO PROFILE(EMAIL, NAME, REG_ID, ANDROID_ID) VALUES(?, ?, ?, ?)")){
    				// Bind the variables to the parameter as strings. 
    				$stmt->bind_param("ssss", $email, $name, $regId, $androidId);
    				
    				// Execute the statement.
    				$result = $stmt->execute(); 				    			    			
    				
    				// successfully inserted into database
    				if ($result) {
    					//return friends list
    					getFriends($email, $mysqli);
    				}
    				// unsuccessfully inserted into database
    				else{    					
				        $response["success"] = 0;
				        $response["message"] = mysqli_error($mysqli);
				 
				        // echoing JSON response
				        echo json_encode($response);
    				}		
    			}
    			else{
		    		$response["success"] = 0;
				$response["message"] = "Failed to insert data";
				 
				// echoing JSON response
				echo json_encode($response);
    			}  
    		
    		} 
    		
    		// Close the prepared statement.
    		$stmt->close();   	
	}
	else{
    		$response["success"] = 0;
		$response["message"] = "Failed to fetch data";
				 
		// echoing JSON response
		echo json_encode($response);
    	}  
	
	mysqli_close($mysqli);
}	
else{
    // required field is missing
    $response["success"] = 0;
    $response["message"] = "Required field(s) is missing";
 
    // echoing JSON response
    echo json_encode($response);
}

//function to return friends of email in argument
function getFriends($email, $mysqli){
	//statment to fetch friends
	if($stmt = $mysqli->prepare("SELECT EMAIL_2, NAME_2, STATUS FROM FRIENDS WHERE EMAIL_1 = ?")){
		// Bind a variable to the parameter as a string. 
    		$stmt->bind_param("s", $email);
    		
    		// Execute the statement.
	    	$stmt->execute();  
	    	
	    	//get rows for the friends if any
    		$stmt->bind_result($friends_email, $friends_name, $status);
    		
    		while ($stmt->fetch()) {    		
    			$all_friends_emails[] = $friends_email;			  			
    			$all_friends_names[] = $friends_name;	
    			
    			if(strcmp($status, 'requested') == 0){
    				$all_status[] = 'request sent';
    			}
    			else{
    				$all_status[] = $status;
    			}		  			    			
		}
		
		//statement to fetch emails whose friends we are
		if($stmt = $mysqli->prepare("SELECT EMAIL_1, NAME_1, STATUS FROM FRIENDS WHERE EMAIL_2 = ?")){
			// Bind a variable to the parameter as a string. 
	    		$stmt->bind_param("s", $email);
	    		
	    		// Execute the statement.
		    	$stmt->execute();  
		    	
		    	//get rows for the friends if any
	    		$stmt->bind_result($friends_email, $friends_name, $status);
	    		
	    		while ($stmt->fetch()) {    		
	    			$all_friends_emails[] = $friends_email;			  			
	    			$all_friends_names[] = $friends_name;	
	    			
	    			if(strcmp($status, 'requested') == 0){
	    				$all_status[] = 'request received';
		    		}
		    		else{
		    			$all_status[] = $status;
		    		}		  			    			
			}
		}
		else{
			$response["success"] = 0;
			$response["message"] = "Failed to fetch friends";
					 
			// echoing JSON response
			echo json_encode($response);
    		}
    		
    		//get if sync file is available
    		$file_status[] = checkZipSyncFile($email);
    		
    		//return friends' names
    		if((isset($all_friends_emails) && !is_null($all_friends_emails)) || (isset($all_friends_names) && !is_null($all_friends_names))){
			echo json_encode(array('all_friends_emails'=>$all_friends_emails, 'all_friends_names'=>$all_friends_names, 'all_status'=>$all_status, 'sync_file'=>$file_status));			
		}
		else{			
			//send back that no friends were found
			$all_friends_emails[] = "no friends found";
			
			echo json_encode(array('all_friends_emails'=>$all_friends_emails, 'sync_file'=>$file_status));
		}
    		
	}
	else{
		$response["success"] = 0;
		$response["message"] = "Failed to fetch friends";
				 
		// echoing JSON response
		echo json_encode($response);
    	}	
}

//function to check if zip sync file exists for this email
function checkZipSyncFile($email){	
	//convert email to zip file name
	$file_name = str_replace("@", "at", $email);
	$file_name = str_replace(".", "dot", $file_name);
	$file_name = $file_name . ".zip";
	
	//add file path to file name
	$file_path = "../SyncZipFiles/";
	$file_name = $file_path . $file_name;
	
	if(file_exists ($file_name)){	
		return filemtime ($file_name);	
	}
	else{
		return "file not found";
	}
}

?>